## [0.0.88](https://github.com/helmut-hoffer-von-ankershoffen/starbridge/compare/v0.0.87..v0.0.88) - 2025-03-14

### 📚 Documentation

- Consistency - ([4063dc8](https://github.com/helmut-hoffer-von-ankershoffen/starbridge/commit/4063dc8e8003634372955aa45a5964d00a716038))



